==> haskell-should-not-typecheck-2.1.0-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-5fPK44wFbt1DhgqCaiJMCm
key: should-not-typecheck-2.1.0-5fPK44wFbt1DhgqCaiJMCm
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 9d8e834cda1b47d5a8c39313199b5f20
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-5fPK44wFbt1DhgqCaiJMCm
depends:
    base-4.11.1.0 HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-57CwdvxkwG5GS0LZ9ydf7i
key: should-not-typecheck-2.1.0-57CwdvxkwG5GS0LZ9ydf7i
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 9b057a695ae027fc92ccdce19af87bdb
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-57CwdvxkwG5GS0LZ9ydf7i
depends:
    base-4.11.1.0 HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
